Index: src/uk/me/parabola/imgfmt/app/dem/DEMFile.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/dem/DEMFile.java	(revision 4168)
+++ src/uk/me/parabola/imgfmt/app/dem/DEMFile.java	(working copy)
@@ -13,6 +13,7 @@
 
 package uk.me.parabola.imgfmt.app.dem;
 
+import java.util.ArrayList;
 import java.util.List;
 
 import uk.me.parabola.imgfmt.Utils;
@@ -71,7 +72,7 @@
 	 * @return a new bounding box that should be used for the TRE file
 	 */
 	public Area calc(Area area, java.awt.geom.Area demPolygonMapUnits, String pathToHGT, List<Integer> pointDistances,
-			short outsidePolygonHeight, InterpolationMethod interpolationMethod) {
+			short outsidePolygonHeight, InterpolationMethod interpolationMethod, int emptyLevelDist) {
 		// HGT area is extended by EXTRA degrees in each direction
 		HGTConverter hgtConverter = new HGTConverter(pathToHGT, area, demPolygonMapUnits, EXTRA);
 		hgtConverter.setInterpolationMethod(interpolationMethod);
@@ -89,6 +90,10 @@
 		int right = treArea.getMaxLong() * 256;
 
 		int zoom = 0;
+		if (emptyLevelDist > 0) {
+			pointDistances = new ArrayList<>(pointDistances);
+			pointDistances.add(emptyLevelDist);
+		}
 		int lastDist = pointDistances.get(pointDistances.size() - 1);
 		for (int pointDist : pointDistances) {
 			int distance = pointDist;
@@ -109,6 +114,8 @@
 				xLeft = moveLeft(left, distance);
 			}
 
+			hgtConverter.setEmptyMode(emptyLevelDist == pointDist);
+				
 			DEMSection section = new DEMSection(zoom++, xTop, xLeft, xTop - bottom, right - xLeft, hgtConverter,
 					distance, pointDist == lastDist);
 			demHeader.addSection(section);
Index: src/uk/me/parabola/mkgmap/build/MapBuilder.java
===================================================================
--- src/uk/me/parabola/mkgmap/build/MapBuilder.java	(revision 4168)
+++ src/uk/me/parabola/mkgmap/build/MapBuilder.java	(working copy)
@@ -169,6 +169,7 @@
 	private short demOutsidePolygonHeight;
 	private java.awt.geom.Area demPolygon;
 	private HGTConverter.InterpolationMethod demInterpolationMethod;
+	private int demEmptyDist;
 	
 
 	public MapBuilder() {
@@ -216,6 +217,8 @@
 		pathToHGT = props.getProperty("dem", null);
 		demDists = parseDemDists(props.getProperty("dem-dists", "-1"));
 		demOutsidePolygonHeight = (short) props.getProperty("dem-outside-polygon", HGTReader.UNDEF);
+		demEmptyDist = props.getProperty("dem-empty-dist", -1);
+		
 		String demPolygonFile = props.getProperty("dem-poly", null);
 		if (demPolygonFile != null) {
 			demPolygon = Java2DConverter.readPolyFile(demPolygonFile);
@@ -332,13 +335,16 @@
 						demArea = demPolygon;
 					}					
 				} 
+				int emptyLevelDist = demEmptyDist;
+
 				if (demArea == null && src instanceof OverviewMapDataSource) {
 					Path2D demPoly = ((OverviewMapDataSource) src).getTileAreaPath();
 					if (demPoly != null) {
 						demArea = new java.awt.geom.Area(demPoly);
 					}
+					emptyLevelDist = -1;
 				}
-				Area treArea = demFile.calc(src.getBounds(), demArea, pathToHGT, demDists, demOutsidePolygonHeight, demInterpolationMethod);
+				Area treArea = demFile.calc(src.getBounds(), demArea, pathToHGT, demDists, demOutsidePolygonHeight, demInterpolationMethod, emptyLevelDist);
 				map.setBounds(treArea);
 				long t2 = System.currentTimeMillis();
 				log.info("DEM file calculation for", map.getFilename(), "took", (t2 - t1), "ms");
Index: src/uk/me/parabola/mkgmap/reader/hgt/HGTConverter.java
===================================================================
--- src/uk/me/parabola/mkgmap/reader/hgt/HGTConverter.java	(revision 4168)
+++ src/uk/me/parabola/mkgmap/reader/hgt/HGTConverter.java	(working copy)
@@ -47,6 +47,7 @@
 	private int statRdrNull;
 	private int statRdrRes;
 	private InterpolationMethod interpolationMethod = InterpolationMethod.Bicubic;
+	private boolean emptyMode;
 
 	public enum InterpolationMethod {
 		/** faster, smoothing, less precise */
@@ -118,6 +119,10 @@
 	 * @return height in m or Short.MIN_VALUE if value is invalid 
 	 */
 	protected short getElevation(int lat32, int lon32) {
+		if (emptyMode)
+			return 0; // HGTReader.UNDEF doesn't seem to work
+		
+
 		int row = (int) ((lat32 - minLat32) * FACTOR);
 		int col = (int) ((lon32 - minLon32) * FACTOR);
 
@@ -674,4 +679,8 @@
 			return cubicInterpolation(arr, qx);
 	}
 
+	public void setEmptyMode(boolean b) {
+		this.emptyMode = b;
+	}
+
 }
